<?php
namespace Teknisa\CADFIS\Strategies;

use Teknisa\Libs\Util\Environment;
use Teknisa\CADFIS\Strategies\GeneralStrategy;
use Teknisa\CADFIS\Services\MarcProdService as MarcProdService;

class MarcProdStrategy extends GeneralStrategy implements Interfaces\IStrategy
{
    protected $service;
    protected $errors = array();
    
    public function __construct(MarcProdService $service, Environment $environment)
    {
		$this->service = $service;
		$this->environment = $environment;
	}
	
	public function validate(&$data)
    {
        //parent::verifyIsEmpty($data);
        
        foreach ($data as &$row) {
            parent::verifyIsEmpty($row, $row["ROWNUM"], ['CDMARCA', 'CDARVPROD']);
            parent::verifyCdMarca($row, $row["ROWNUM"]);
            self::verifyMarcaExists($row, $row["ROWNUM"]);
            parent::verifyCdProduto($row, $row["ROWNUM"]);
            self::verifyMarcProdExists($row, $row["ROWNUM"]);
            
            $row['ERROS'] = $this->errors;
            
            parent::clearErrors();
        }
    }
    
    private function verifyMarcaExists($row, $rowNum)
    {
        if (!$this->service->verifyMarcaExists($row)) {
            parent::setError($rowNum, 'CDMARCA', $row['CDMARCA'], "UNREGISTERED");
        }
    }
    
    private function verifyMarcProdExists($row, $rowNum)
    {
        if ($this->service->verifyMarcProdExists($row)) {
            parent::setError($rowNum, 'CDMARCA/CDARVPROD', $row['CDMARCA'].'/'.$row['CDARVPROD'], "ALREADY_REGISTERED");
        }
    }
    
    public function formatToView(&$data)
    {
        foreach ($data as &$row) {
           $row['CDMARCA'] = parent::formatColumn($row['CDMARCA'], 5);
           $row['IDERROR'] = !empty($row['ERROS']) ? 'S' : 'N';
        }
    }
    
    public function formatToSave(&$data)
    {
        foreach ($data as &$row) {
            $row['__is_new'] = true;
            $row['IDMARCAPROV']     = 'S';
            $row['IDAUTORIZ']       = 'N';
            $row['DTVALAPROV']      = NULL;
            $row['VRRENDATUMAR']    = 0;
            $row['IDTIPREND']       = 'P';
            $row['DTULTATUMAPR']    = NULL;
            $row['VRARREDEMPMAR']   = NULL;
            $row['NRORG']           = $this->environment->getNrorg();
            $row['DTINCLUSAO']      = NULL;
            $row['DTULTATU']        = NULL;
            $row['NRORGINCLUSAO']   = $this->environment->getNrorg();
            $row['CDOPERINCLUSAO']  = $this->environment->getCdOperador();
            $row['NRORGULTATU']     = $this->environment->getNrorg();
            $row['CDOPERULTATU']    = $this->environment->getCdOperador();
            $row['IDATIVO']         = 'S';
        } 
    }
    
    public function save($data)
    {
        self::validate($data);
        parent::verifyExistErros($data);
        $this->service->saveImport($data);
    }
}