<?php
/**
 * GepObservacaoativLogic.
 *
 * @package Logic.
 * @author  erikasouza
 *
 */
class GepObservacaoativLogic{


     /**
     * Gera o novo codigo de Observacao da Atividade.
     *
     * @param  $nrorg  integer Numero da organizacao.
     *
     * @return $codigo integer
     */
    public static function retornaProxNumObservacaoAtiv($nrorg){
        $codigo = GepObservacaoativEntity::retornaProxNumObservacaoAtiv($nrorg);
        return $codigo;
    }


    /**
     * Retorna registro de observa? de um parceiro de negocio.
     *
     * @param integer $nrorg         Numero da Organiza?.
     * @param integer $nratividade   Numero da atividade.
     * @param integer $nrparcnegocio Numero do Parceiro de negocio.
     *
     * @return GepObservacaoativ|boolean|void
     */
    public static function retornaObservacaoParcNegocio($nrorg, $nratividade, $nrparcnegocio){
        try {
            $resultado = GepObservacaoativEntity::retornaObservacaoParcNegocio(
                $nrorg,
                $nratividade,
                $nrparcnegocio
            );
            return $resultado;
        } catch (Exception $e) {
            switch ($e->getCode()){
            case GepObservacaoativEntity::SEM_REGISTRO:
                return false;
            default:
                return tk_message('Erro desconhecido: '.$e->getMessage());
            }
        }
    }


    /**
     * Salva observacao do operador.
     *
     * @param integer $nratividade        Numero da atividade.
     * @param integer $nrparcnegoobserv   Numero do parceiro de negocio da observacao.
     * @param string  $txobservacao       Texto da observacao.
     * @param integer $nrorg              Numero da organizacao de atualizacao.
     * @param integer $cdoperador         Numero do operador de atualizacao.
     * @param date    $data               Data de atualizacao.
     *
     * @return boolean
     */
    public static function salvaObservacaoOperador(
        $nratividade,
        $nrparcnegoobserv,
        $txobservacao,
        $nrorg,
        $cdoperador,
        $data
    ){
        $registro = self::retornaObservacaoParcNegocio($nrorg, $nratividade, $nrparcnegoobserv);
        if ($registro === false) {
            if (empty($txobservacao) === false) {
                $nrobservacao = self::retornaProxNumObservacaoAtiv($nrorg);
                GepObservacaoativEntity::insereObservacaoOperador(
                    $nratividade,
                    $nrobservacao,
                    $nrparcnegoobserv,
                    $txobservacao,
                    $nrorg,
                    $cdoperador,
                    $data
                );

            }
            return false;
        } else {
            GepObservacaoativEntity::atualizaObservacaoOperador(
                $nratividade,
                $nrparcnegoobserv,
                $txobservacao,
                $nrorg,
                $cdoperador,
                $data
            );

        }

        return true;

    }


}